gunfolds
========

Tools to explore dynamic causal graphs in the case of  undersampled data helping to unfold the apparent structure into the underlying truth.

Documentation
===================
Please refer to the [Documentation](https://neuroneural.github.io/gunfolds/) for more information.

Installation
============

Install the gunfolds package

```bash
   pip install gunfolds
```

Additionally, install these packages to use gunfolds
   
graph-tool installation
-------------------------  
**1. Install** ``graph-tool``

To install ``graph-tool`` package with **conda install** run the following command

```bash
   conda install -c conda-forge graph-tool
```
   
To install ``graph-tool`` package with **brew install** run the following command

```bash
   brew install graph-tool
```

PyGObject installation
-------------------------
**2. Install** ``PyGObject``

**This is only required if you need to use** ``gtool`` **module of the** ``gunfolds`` **package**

To install ``PyGObject`` package with **brew install** run the following command

```bash
   brew install pygobject3 gtk+3
```

To install ``PyGObject`` package in Windows, Linux and any other platforms please refer to the link

   https://pygobject.readthedocs.io/en/latest/getting_started.html

Acknowledgment
========
This work was initially supported by  NSF IIS-1318759 grant and is currently supported by NIH 1R01MH129047.
